@@ -378,20 +378,28 @@ class TRMaid(object):
         return req
 
     def add_links(self, section, subsection, links, rss=False):
+        if rss:
+            rdskey = 'trmaid:added:%s:%s' % (
+                hashlib.md5(subsection).hexdigest(),
+                urlparse(subsection).hostname,
+            )
+            existing = self.rds.lrange(rdskey, 0, -1)
+        else:
+            rdskey = None
+            existing = []
+
         ids = []
-        rdskey = 'trmaid:added:%s' % hashlib.md5(subsection).hexdigest()
-        radded = rss and self.rds.lrange(rdskey, 0, -1) or []
         add_req = self.get_torrent_add_args(section, subsection)
 
         for link in links:
             xhash = hashlib.md5(link).hexdigest()
-            if xhash in radded:
+            if xhash in existing:
                 continue
             add_req['filename'] = link
             res = self.verbose_func(self.rpc.torrent_add, add_req)
             result = res.get('result', '')
 
-            if rss and result in ['success', 'duplicate torrent']:
+            if rdskey and result in ['success', 'duplicate torrent']:
                 self.rds.lpush(rdskey, xhash)
 
             if result != 'success':
@@ -403,7 +411,7 @@ class TRMaid(object):
                 ids.append(arguments['torrent-added']['id'])
 
         if ids:
-            if rss:
+            if rdskey:
                 self.rds.ltrim(rdskey, 0, 1000)
             set_req = self.get_torrent_set_args(section, subsection)
             set_req['ids'] = ids
@@ -438,6 +446,7 @@ class TRMaid(object):
         self.handle_redis()
         self.handle_all_torrents()
 
+
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument(
